# 32/64bit spec
#
Summary:   A fast, lightweight distributed source control management system
Summary(de): Ein schnelles und leichtgewichtiges Quellkodeverwaltungssystem
Name:      mercurial
Version:   2.7.2
Release:   %mkrel 1
License:   GPLv2+
Group:     Development/Other
URL: 	   http://www.selenic.com/mercurial/
Source0:   http://www.selenic.com/mercurial/release/%{name}-%{version}.tar.xz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: python-devel
BuildRequires: xmlto
BuildRequires: asciidoc
BuildRequires: python-docutils
Provides: hg = %{version}-%{release}


%description
Mercurial is a fast, lightweight source control management system
designed for efficient handling of very large distributed
projects. Major features include:

* Extremely high-performance delta-compressed storage scheme
* Optimized for disk layout and access efficiency
* Complete cross-indexing of files and changesets
* Bandwidth and CPU efficient HTTP and SSH sync protocols 
* Distributed development model supports unlimited numbers of developers
* Allows arbitrary merging between developer branches
* Doesn't significantly degrade with large numbers of files or changesets
* No waiting for locks! 
* SHA1 integrity checking on repository data
* Append-only storage model with transaction journalling
* Fast full-repository verification
* Convenient backup 
* Most commands are familiar to users of CVS and other systems
* Built-in command help
* Integrated stand-alone web interface (example)
* Works with various GUI tools 
* Runs on UNIX, MacOS X, and Windows
* Conversion tools available for many popular SCMs
* Allows a variety of usage models
* Supports user-defined hooks and extensions 
* Source code available under the GPL license
* Actively community supported and developed

%description -l de
Mercurial ist ein schnelles, leichtgewichtiges Quellkodeverwaltungssystem, mit dem Ziel der
effizienten Handhabung von sehr großen verteilten Projekten.
Haupteigenschaften sind:

* delta-komprimierte Datei Speicherung und Retrieval-System 
* Vollständige Kreuz-Indizierung von Datei-und changesets für eine effiziente exploration Geschichte des Projekts 
* Robuste SHA1-Integritätsprüfung und append-only Lagerung Modell 
* Dezentrale Entwicklung Modell mit beliebigen Verschmelzung zwischen Verzeichnisse 
* High-Speed-HTTP-basierten Netzwerk-Protokoll Fusionierung 
* Easy-to-use Befehlszeilen-Schnittstelle 
* Integrierter Stand-Alone Web-Interface 
* Kleine Python-Codebasis 

%prep
%setup -q

%build
%make all

%install
%__rm -rf $RPM_BUILD_ROOT
PYTHONDONTWRITEBYTECODE= %__python setup.py install -O1 --root $RPM_BUILD_ROOT --prefix %{_prefix} --record=%{name}.files
make install-doc DESTDIR=$RPM_BUILD_ROOT MANDIR=%{_mandir}

install contrib/hgk          $RPM_BUILD_ROOT%{_bindir}
install contrib/convert-repo $RPM_BUILD_ROOT%{_bindir}/mercurial-convert-repo
install contrib/hg-ssh       $RPM_BUILD_ROOT%{_bindir}

bash_completion_dir=$RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d
mkdir -p $bash_completion_dir
install -m 644 contrib/bash_completion $bash_completion_dir/mercurial.sh

zsh_completion_dir=$RPM_BUILD_ROOT%{_datadir}/zsh/site-functions
mkdir -p $zsh_completion_dir
install -m 644 contrib/zsh_completion $zsh_completion_dir/_mercurial

lisp_dir=$RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
mkdir -p $lisp_dir
install -m 644 contrib/mercurial.el $lisp_dir
install -m 644 contrib/mq.el $lisp_dir

xlisp_dir=$RPM_BUILD_ROOT%{_datadir}/xemacs/site-packages/lisp
mkdir -p $xlisp_dir
install -m 644 contrib/mercurial.el $xlisp_dir
install -m 644 contrib/mq.el $xlisp_dir

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/mercurial/hgrc.d
install -m 644 contrib/mergetools.hgrc $RPM_BUILD_ROOT/%{_sysconfdir}/mercurial/hgrc.d/mergetools.rc

%clean
%__rm -rf $RPM_BUILD_ROOT

%files -f %{name}.files
%defattr(-,root,root,-)
%doc CONTRIBUTORS COPYING doc/README doc/hg*.txt doc/hg*.html *.cgi contrib/*.fcgi
%doc %attr(644,root,root) contrib/*.svg contrib/sample.hgrc
%dir %{_sysconfdir}/mercurial
%dir %{_sysconfdir}/mercurial/hgrc.d
%config(noreplace) %{_sysconfdir}/mercurial/hgrc.d/mergetools.rc
%{_mandir}/man*/*
%{_sysconfdir}/bash_completion.d/mercurial.sh
%{_datadir}/zsh/site-functions/_mercurial
%{_datadir}/emacs/site-lisp/*.el
%{_datadir}/xemacs/site-packages/lisp/*.el
%{_bindir}/hgk
%{_bindir}/hg-ssh
%{_bindir}/mercurial-convert-repo



%changelog
* Fri Oct 11 2013 ghostbunny <hmhaase at pclinuxosusers dot de> 2.7.2-1pclos2013
- 2.7.2

* Sat Aug 17 2013 billybot <billybot> 2.6.2-2pclos2013
- update python 2.7

* Thu Jun 06 2013 ghostbunny <hmhaase at pclinuxosusers dot de> 2.6.2-1pclos2013
- 2.6.2

* Sun May 05 2013 ghostbunny <hmhaase at pclinuxosusers dot de> 2.6-1pclos2013
- 2.6

* Wed Mar 06 2013 ghostbunny <hmhaase at pclinuxosusers dot de> 2.5.2-1pclos2013
- 2.5.2

* Tue Feb 05 2013 ghostbunny <hmhaase at pclinuxosusers dot de> 2.5-1pclos2013
- 2.5

* Tue Jan 08 2013 ghostbunny <hmhaase at pclinuxosusers dot de> 2.4.2-1pclos2013
- 2.4.2

* Thu Nov 22 2012 Neal <nealbrks0 at gmail dot com> 2.4-1pclos2012
- process

* Mon Nov 19 2012 ghostbunny <hmhaase at pclinuxosusers dot de> 2.4-1pclos2012
- 2.4

* Tue Oct 09 2012 Neal <nealbrks0 at gmail dot com> 2.3.2-1pclos2012
- process

* Tue Oct 09 2012 ghostbunny <hmhaase at pclinuxosusers dot de> 2.3.2-1pclos2012
- 2.3.2

* Sun Sep 09 2012 Neal <nealbrks0 at gmail dot com> 2.3.1-1pclos2012
- process

* Sun Sep 09 2012 ghostbunny <hmhaase at pclinuxosusers dot de> 2.3.1-1pclos2012
- 2.3.1

* Thu Aug 23 2012 Neal <nealbrks0 at gmail dot com> 2.3-1pclos2012
- process

* Thu Aug 23 2012 ghostbunny <hmhaase at pclinuxosusers dot de> 2.3-1pclos2012
- 2.3

* Mon Jul 16 2012 Neal <nealbrks0 at gmail dot com> 2.2.3-1pclos2012
- process

* Mon Jul 16 2012 ghostbunny <hmhaase at pclinuxosusers dot de> 2.2.3-1pclos2012
- 2.2.3
- added german summary

* Sun Jun 10 2012 Neal <nealbrks0 at gmail dot com> 2.2.2-1pclos2012
- process

* Sun Jun 10 2012 ghostbunny <hmhaase at pclinuxosusers dot de> 2.2.2-1pclos2012
- 2.2.2

* Wed May 23 2012 Neal <nealbrks0 at gmail dot com> 2.2.1-1pclos2012
- process

* Wed May 23 2012 ghostbunny <hmhaase at pclinuxosusers dot de> 2.2.1-1pclos2012
- 2.2.1

* Tue Apr 17 2012 Neal <nealbrks0 at gmail.com> 2.1.2-1pclos2012
- process

* Tue Apr 17 2012 ghostbunny <hmhaase at pclinuxosusers dot de> 2.1.2-1pclos2012
- 2.1.2

* Thu Sep 22 2011 Texstar <texstar at gmail.com> 1.9.2-1pclos2011
- 1.9.2
